@@ -363,7 +363,9 @@ define ([
             r += '   unresponsive, make sure browser window is active and press \'TAB\'</span>';
             r += '</div>';
 
-            r += '<div class="mainarea" id="mainarea"></div>';
+            r += '<div class="mainarea" id="mainarea">';
+            r += '<br><br><br><br><br><center><p>LOADING . . . PLEASE WAIT</p></center><br><br><br><br><br>';
+            r += '</div>';
 
             r += '<div class="boxtopbot" id="result">&nbsp;</div>';
 
@@ -588,7 +590,7 @@ define ([
                 for (i = 1; i < len; i += 1) {
                     // the entries are names of targets
                     entry = menuObj.entries[i];
-                    r += i + '. ' + entry.menuText + '<br>';
+                    r += i + '.&nbsp;' + entry.menuText + '<br>';
                 }
             }
             r += 'X. Exit/back<br>';
